@@ -12,17 +12,13 @@ from flupy import flu
 from alembic_utils.cache import cachedmethod
 from alembic_utils.exceptions import DuplicateRegistration
 from alembic_utils.reversible_op import ReversibleOp
+from alembic_utils.statement import normalize_whitespace, strip_terminating_semicolon
 
 log = logging.getLogger(__name__)
 
 T = TypeVar("T", bound="ReplaceableEntity")
 
 
-def normalize_whitespace(text, base_whitespace: str = " ") -> str:
-    """ Convert all whitespace to *base_whitespace* """
-    return base_whitespace.join(text.split()).strip()
-
-
 @contextmanager
 def simulate_entity(connection, entity):
     """Creates *entity* in the *dummy_schema* and self would be transformed into if it were created in the database"""
@@ -30,6 +26,7 @@ def simulate_entity(connection, entity):
     assert entity.schema == dummy_schema
     cls = entity.__class__
     adj_target = cls(dummy_schema, entity.signature, entity.definition)
+    connection.execute("begin")
     connection.execute(f"drop schema if exists {dummy_schema} cascade")
     connection.execute(f"create schema if not exists {dummy_schema}")
     try:
@@ -37,6 +34,7 @@ def simulate_entity(connection, entity):
         yield
     finally:
         connection.execute(f"drop schema if exists {dummy_schema} cascade")
+        connection.execute("rollback")
 
 
 class ReplaceableEntity:
@@ -47,7 +45,7 @@ class ReplaceableEntity:
     def __init__(self, schema: str, signature: str, definition: str):
         self.schema: str = normalize_whitespace(schema)
         self.signature: str = normalize_whitespace(signature)
-        self.definition: str = definition.strip()
+        self.definition: str = strip_terminating_semicolon(definition)
 
     @classmethod
     def from_sql(cls: Type[T], sql: str) -> T:
@@ -238,20 +236,20 @@ class RevertOp(ReversibleOp):
 
 
 @Operations.implementation_for(CreateOp)
-def create_function(operations, operation):
+def create_entity(operations, operation):
     target: ReplaceableEntity = operation.target
     operations.execute(target.to_sql_statement_create())
 
 
 @Operations.implementation_for(DropOp)
-def drop_function(operations, operation):
+def drop_entity(operations, operation):
     target: ReplaceableEntity = operation.target
     operations.execute(target.to_sql_statement_drop())
 
 
 @Operations.implementation_for(ReplaceOp)
 @Operations.implementation_for(RevertOp)
-def replace_or_revert_function(operations, operation):
+def replace_or_revert_entity(operations, operation):
     target: ReplaceableEntity = operation.target
     operations.execute(target.to_sql_statement_create_or_replace())
 
@@ -262,7 +260,7 @@ def replace_or_revert_function(operations, operation):
 
 
 @renderers.dispatch_for(CreateOp)
-def render_create_function(autogen_context, op):
+def render_create_entity(autogen_context, op):
     target = op.target
     autogen_context.imports.add(target.render_import_statement())
     variable_name = target.to_variable_name()
@@ -270,17 +268,17 @@ def render_create_function(autogen_context, op):
 
 
 @renderers.dispatch_for(DropOp)
-def render_drop_function(autogen_context, op):
+def render_drop_entity(autogen_context, op):
     target = op.target
     autogen_context.imports.add(target.render_import_statement())
     variable_name = target.to_variable_name()
     return (
-        target.render_self_for_migration(omit_definition=True) + f"op.drop_entity({variable_name})"
+        target.render_self_for_migration(omit_definition=False) + f"op.drop_entity({variable_name})"
     )
 
 
 @renderers.dispatch_for(ReplaceOp)
-def render_replace_function(autogen_context, op):
+def render_replace_entity(autogen_context, op):
     target = op.target
     autogen_context.imports.add(target.render_import_statement())
     variable_name = target.to_variable_name()
@@ -288,8 +286,8 @@ def render_replace_function(autogen_context, op):
 
 
 @renderers.dispatch_for(RevertOp)
-def render_revert_function(autogen_context, op):
-    """Collect the function definition currently live in the database and use its definition
+def render_revert_entity(autogen_context, op):
+    """Collect the entity definition currently live in the database and use its definition
     as the downgrade revert target"""
     target = op.target
     autogen_context.imports.add(target.render_import_statement())
